@@ -88,7 +88,7 @@ class Crp:
 
 # --------------------------------------------------------------------------------------------------------------------------
 
-    def getTargetValues(self,rain_data,target_data):
+    def getTargetValues(self,train_data,target_data):
         """
         Params:
             train_data  ->
